@@ -1,6 +1,6 @@
 package Bundle::COG;
 
-$VERSION = '0.04';
+$VERSION = '0.05';
 
 =head1 NAME
 
@@ -14,6 +14,10 @@ cpan Bundle::COG
 
 Acme::AsciiArt2HtmlTable
 
+Business::PT::BI
+
+Business::PT::NIF
+
 Date::Holidays::PT
 
 File::Munger
@@ -56,6 +60,8 @@ Text::Beautify
 
 Text::Ngram
 
+WWW::Dictionary
+
 =head1 AUTHOR
 
 Jose Castro, C<< <cog@cpan.org> >>
